# parts: XL4015

- XL4015: 8 - 36 VDC -> 1.25 - 32 VDC, 5A
- specs: [XL4015](https://www.handsontec.com/dataspecs/module/XL4015-5A-PS.pdf)

|   |
| --- |
| ![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/XL4015.png?raw=true) |
